
xtensors
############
`xtensors` is a named tensor utility library.


Installation
=============
Install with :code:`pip`:

.. code-block:: console

    pip install xtensors



Documentation
==============
Documentaion is available on `<https://xtensors.readthedocs.io/en/latest>`_
